'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var tslib = require('tslib');
var listfield = require('./listfield.js');
var mapfield = require('./mapfield.js');
var registerfield = require('./registerfield.js');
var textfield = require('./textfield.js');
require('@lumino/algorithm');
require('./field.js');
require('./utilities.js');

/**
 * The namespace for the `Fields` factory functions.
 */
exports.Fields = void 0;
(function (Fields) {
    /**
     * A factory function which creates a boolean register field.
     *
     * @param options - The options for the field. The default `value`
     *   option is `false`.
     *
     * @returns A new boolean register field.
     */
    function Boolean(options) {
        if (options === void 0) { options = {}; }
        return new registerfield.RegisterField(tslib.__assign({ value: false }, options));
    }
    Fields.Boolean = Boolean;
    /**
     * A factory function which creates a number register field.
     *
     * @param options - The options for the field. The default `value`
     *   option is `0`.
     *
     * @returns A new number register field.
     */
    function Number(options) {
        if (options === void 0) { options = {}; }
        return new registerfield.RegisterField(tslib.__assign({ value: 0 }, options));
    }
    Fields.Number = Number;
    /**
     * A factory function which creates a string register field.
     *
     * @param options - The options for the field. The default `value`
     *   option is `''`.
     *
     * @returns A new string register field.
     */
    function String(options) {
        if (options === void 0) { options = {}; }
        return new registerfield.RegisterField(tslib.__assign({ value: '' }, options));
    }
    Fields.String = String;
    /**
     * A factory function which creates a list field.
     *
     * @param options - The options for the field.
     *
     * @returns A new list field.
     */
    function List(options) {
        if (options === void 0) { options = {}; }
        return new listfield.ListField(options);
    }
    Fields.List = List;
    /**
     * A factory function which creates a map field.
     *
     * @param options - The options for the field.
     *
     * @returns A new map field.
     */
    function Map(options) {
        if (options === void 0) { options = {}; }
        return new mapfield.MapField(options);
    }
    Fields.Map = Map;
    /**
     * A factory function which creates a register field.
     *
     * @param options - The options for the field.
     *
     * @returns A new register field.
     */
    function Register(options) {
        return new registerfield.RegisterField(options);
    }
    Fields.Register = Register;
    /**
     * A factory function which creates a text field.
     *
     * @param options - The options for the field.
     *
     * @returns A new text field.
     */
    function Text(options) {
        if (options === void 0) { options = {}; }
        return new textfield.TextField(options);
    }
    Fields.Text = Text;
})(exports.Fields || (exports.Fields = {}));
//# sourceMappingURL=fields.js.map
