import { ReadonlyJSONValue } from '@lumino/coreutils';
import { ListField } from './listfield';
import { MapField } from './mapfield';
import { RegisterField } from './registerfield';
import { TextField } from './textfield';
/**
 * The namespace for the `Fields` factory functions.
 */
export declare namespace Fields {
    /**
     * A factory function which creates a boolean register field.
     *
     * @param options - The options for the field. The default `value`
     *   option is `false`.
     *
     * @returns A new boolean register field.
     */
    function Boolean(options?: Partial<RegisterField.IOptions<boolean>>): RegisterField<boolean>;
    /**
     * A factory function which creates a number register field.
     *
     * @param options - The options for the field. The default `value`
     *   option is `0`.
     *
     * @returns A new number register field.
     */
    function Number(options?: Partial<RegisterField.IOptions<number>>): RegisterField<number>;
    /**
     * A factory function which creates a string register field.
     *
     * @param options - The options for the field. The default `value`
     *   option is `''`.
     *
     * @returns A new string register field.
     */
    function String(options?: Partial<RegisterField.IOptions<string>>): RegisterField<string>;
    /**
     * A factory function which creates a list field.
     *
     * @param options - The options for the field.
     *
     * @returns A new list field.
     */
    function List<T extends ReadonlyJSONValue>(options?: ListField.IOptions<T>): ListField<T>;
    /**
     * A factory function which creates a map field.
     *
     * @param options - The options for the field.
     *
     * @returns A new map field.
     */
    function Map<T extends ReadonlyJSONValue>(options?: MapField.IOptions<T>): MapField<T>;
    /**
     * A factory function which creates a register field.
     *
     * @param options - The options for the field.
     *
     * @returns A new register field.
     */
    function Register<T extends ReadonlyJSONValue>(options: RegisterField.IOptions<T>): RegisterField<T>;
    /**
     * A factory function which creates a text field.
     *
     * @param options - The options for the field.
     *
     * @returns A new text field.
     */
    function Text(options?: TextField.IOptions): TextField;
}
//# sourceMappingURL=fields.d.ts.map