import { Schema } from './schema';
/**
 * A type alias for a datastore record.
 */
export declare type Record<S extends Schema> = Record.Base<S> & Record.Value<S>;
/**
 * The namespace for the `Record` type statics.
 */
export declare namespace Record {
    /**
     * A type alias for the record base type.
     */
    type Base<S extends Schema> = {
        /**
         * The unique id of the record.
         */
        readonly $id: string;
        /**
         * @internal
         *
         * The metadata for the record.
         */
        readonly '@@metadata': Metadata<S>;
    };
    /**
     * A type alias for the record value type.
     */
    type Value<S extends Schema> = {
        readonly [N in keyof S['fields']]: S['fields'][N]['ValueType'];
    };
    /**
     * A type alias for the record update type.
     */
    type Update<S extends Schema> = {
        readonly [N in keyof S['fields']]?: S['fields'][N]['UpdateType'];
    };
    /**
     * A type alias for the record change type.
     */
    type Change<S extends Schema> = {
        readonly [N in keyof S['fields']]?: S['fields'][N]['ChangeType'];
    };
    /**
     * A type alias for the record patch type.
     */
    type Patch<S extends Schema> = {
        readonly [N in keyof S['fields']]?: S['fields'][N]['PatchType'];
    };
    /**
     * @internal
     *
     * A type alias for the record metadata type.
     */
    type Metadata<S extends Schema> = {
        readonly [N in keyof S['fields']]: S['fields'][N]['MetadataType'];
    };
    /**
     * @internal
     *
     * A type alias for the record mutable change type.
     */
    type MutableChange<S extends Schema> = {
        [N in keyof S['fields']]?: S['fields'][N]['ChangeType'];
    };
    /**
     * @internal
     *
     * A type alias for the record mutable patch type.
     */
    type MutablePatch<S extends Schema> = {
        [N in keyof S['fields']]?: S['fields'][N]['PatchType'];
    };
}
//# sourceMappingURL=record.d.ts.map