import { AnyField } from './field';
/**
 * A type definition for a table schema.
 *
 * #### Notes
 * The datastore assumes that peers may safely collaborate on tables
 * which share the same schema `id`.
 *
 * The schema `id` must be changed whenever changes are made to the
 * schema, or undefined behavior will result.
 */
export declare type Schema = {
    /**
     * The unique identifier for the schema.
     */
    readonly id: string;
    /**
     * The field definitions for the schema.
     *
     * #### Notes
     * Field names cannot begin with `$` or `@`.
     */
    readonly fields: {
        readonly [name: string]: AnyField;
    };
};
/**
 * Validate a schema definition.
 */
export declare function validateSchema(schema: Schema): string[];
//# sourceMappingURL=schema.d.ts.map